@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
+# Copyright (c) 1998-2013 Miguel Filgueiras migfilg@t-online.de
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #      along with this program.
 #
 #  File: elevation.tcl
-#  Last change:  22 July 2011
+#  Last change:  6 October 2013
 #
 # This file contains mostly code contributed by Alessandro Palmas
 #   (alpalmas _AT_ tin.it)
@@ -323,9 +323,7 @@ proc Hgraph {k what args} {
 
     # MF contrib
     # prepare to record information related to tags
-    foreach ix [array names HGinfo $c,*] {
-	unset HGinfo($ix)
-    }
+    array unset HGinfo $c,*
     set infolist "" ; set infotag 0
     #----
     # normalize list k
@@ -782,7 +780,7 @@ proc HgraphClose {w} {
     # close elevation graph window and delete information on it
     global HGinfo
 
-    foreach n [array names HGinfo $w.*,*] { unset HGinfo($n) }
+    array unset HGinfo $w.*,*
     destroy $w
     return
 }
